@@ -43,13 +43,13 @@ class Component:
         self.hw_info = None
         self.installs = []
         self.exports = []
-
+        self.private_shldflag = []
         self.depends_on = []  # 该组件被哪个组件依赖,组件句柄列表
         self.need_build = True
         self.loaded = False
 
         self.conditions = []
-
+        self.separate_app = ''
 
 
     def check_file_integrity(self):
@@ -249,6 +249,7 @@ class Component:
         self.name = pack.name
         self.version = pack.version
         self.type = pack.type
+        self.separate_app = pack.separate_app
         self.tag = pack.tag
         self.license = pack.license
         self.description = pack.description
@@ -281,6 +282,34 @@ class Component:
             self.defconfig[ver_key] = "%s_%s_%s" % (self.name, self.version, self.defconfig["SW_VERSION"])
         self.loaded = True
         return True
+    
+    def save_package(self):
+        # if self.type:
+        #     return False
+        print("%s \r\n" % self.name)
+        if not os.path.exists(self.path):
+            os.mkdir(self.path)
+        filename = os.path.join(self.path, 'package.yaml')
+        pack = Package('')
+
+        pack.name = self.name
+        pack.version = self.version
+        pack.type = self.type
+        pack.separate_app = self.separate_app
+        pack.tag = self.tag
+        pack.license = self.license
+        pack.description = self.description
+        pack.source_file = self.source_files
+        pack.build_config = copy.deepcopy(self.build_config)
+        pack.defconfig = copy.deepcopy(self.defconfig)
+        pack.installs = copy.deepcopy(self.install)
+        pack.exports = copy.deepcopy(self.export)
+        pack.hw_info = copy.deepcopy(self.hw_info)
+        pack.save(filename)
+        pack = Package(filename)
+        self.pack = pack
+        self.need_build = True
+        return True
 
     def variable_convert(self, varList):
         # script
