@@ -49,6 +49,9 @@ class HardwareInfo:
                if (k == 'ld_script' and get_compiler() == 'gcc') or (k == 'icc_ld_script' and get_compiler() == 'icc') \
                     or (k == 'armcc_ld_script' and get_compiler() == 'armcc'):
                     self.__dict__['ld_script'] = v
+            elif k in ['uspace_app_ld_script'] and v:
+               if (k == 'uspace_app_ld_script' and get_compiler() == 'gcc'):
+                    self.__dict__['uspace_app_ld_script'] = v
             else:
                 if type(v) == dict:
                     updated_items = {}
@@ -57,6 +60,9 @@ class HardwareInfo:
                             if (kk == 'ld_script' and get_compiler() == 'gcc') or (kk == 'icc_ld_script' and get_compiler() == 'icc') \
                                     or (kk == 'armcc_ld_script' and get_compiler() == 'armcc'):
                                     item['ld_script'] = vv
+                        elif kk in ['uspace_app_ld_script'] and vv:
+                            if (kk == 'uspace_app_ld_script' and get_compiler() == 'gcc'):
+                                    item['uspace_app_ld_script'] = vv
                         elif vv:
                             updated_items[kk] = vv
                     self.cpu_list[k] = updated_items
@@ -86,6 +92,7 @@ class HardwareInfo:
         self.chip_name = ''
         self.board_name = ''
         self.ld_script = ''
+        self.uspace_app_ld_script = ''
         self.flash_program = ''
         self.program_data_files = []
         self.debug_server = ''
@@ -134,6 +141,9 @@ class HardwareInfo:
 
         if self.ld_script:
             self.ld_script = os.path.join(path, self.ld_script)
+        if self.uspace_app_ld_script:
+            self.uspace_app_ld_script = os.path.join(path, self.uspace_app_ld_script)
+
         if self.flash_program:
             self.flash_program = os.path.join(path, self.flash_program)
         if self.debug_server:
@@ -144,7 +154,7 @@ class HardwareInfo:
         for k, v in self.cpu_list.items():
             vv = {}
             for k1, v1 in v.items():
-                if k1 == 'ld_script' or k1 == 'flash_program' or k1 == 'debug_server':
+                if k1 == 'ld_script' or k1 == 'uspace_app_ld_script' or k1 == 'flash_program' or k1 == 'debug_server':
                     v1 = os.path.join(path, v1)
                 elif k1 == 'program_data_files':
                     v1 = update_path_of_data_files(path, v1)
@@ -170,7 +180,7 @@ class HardwareInfo:
                     for k, v in cpu.items():
                         text += '    {}: {}\n'.format(k, v)
         else:
-            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'toolchain_prefix', 'toolchain_path']:
+            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'uspace_app_ld_script', 'toolchain_prefix', 'toolchain_path']:
                 if self.__dict__[k]:
                     text += '  {}: {}\n'.format(k, self.__dict__[k])
 
@@ -278,6 +288,7 @@ class build_config:
         self.libs_updated = []
         self.libpath_updated = []
         self.shldflag = ''
+        self.appldflag = ''
         self.shcflag = ''
         for k, v in dic.items():
             if v:
@@ -287,7 +298,7 @@ class build_config:
         text = ''
         for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'icc_cflag', 'icc_cxxflag', 'icc_asmflag', \
             'icc_ldflag', 'armcc_cflag', 'armcc_cxxflag', 'armcc_asmflag', 'armcc_ldflag', 'shldflag', \
-            'shcflag', 'postimage_script']:
+            'appldflag', 'shcflag', 'postimage_script', 'prebuild_script']:
             value = self.__dict__[k]
             if value:
                 if len(value) < 60:
@@ -421,7 +432,7 @@ class Package(object):
             logger.warn('%s: `version` field cannot be empty!' % filename)
             # exit(-1)
 
-        if self.type not in ['dynamic', 'solution', 'board', 'chip', 'arch', 'drv_core', 'drv_peripheral', 'drv_external_device', 'kernel', 'common', 'sdk', 'document']:
+        if self.type not in ['dynamic', 'solution', 'board', 'chip', 'arch', 'drv_core', 'drv_peripheral', 'drv_external_device', 'kernel', 'common', 'sdk', 'document', 'userspace_common']:
             put_string(
                 '%s: `type` field must be "solution" or "board" or "chip" or "arch" or "drv_core" or "drv_peripheral" or "drv_external_device" or "kernel" or "common" or "sdk" or "document".' % filename)
             exit(-1)
