@@ -7,6 +7,9 @@ from __future__ import print_function
 
 from aostools import *
 import codecs
+import time
+import multiprocessing;
+
 
 class Make(Command):
     common = True
@@ -62,25 +65,30 @@ Make aos program.\n"
                 put_string("Found incompatible version of SCons at %s." % ext_scons)
                 put_string("It is better to uninstall it to avoid unexpected issues.\n")
 
+        num = multiprocessing.cpu_count()
+        multi_thread = "-j" + str(num)
         count = len(cmds)
         if count == 0:
+            starttime = time.time()
             if opt.board:
                 if ext_scons_existed:
                     if params_str.find("V=1") >= 0:
-                        result = os.system("scons --verbose --board=%s %s -j4" % (opt.board, params_str)) >> 8
+                        result = os.system("scons --verbose --board=%s -j%d  %s" % (opt.board, num, params_str)) >> 8
                     else:
-                        result = os.system("scons --board=%s %s -j4" % (opt.board, params_str)) >> 8
+                        result = os.system("scons --board=%s -j%d %s" % (opt.board, num, params_str)) >> 8
                 else:
-                    result = os.system("make BOARD=%s %s" % (opt.board, params_str)) >> 8
+                    result = os.system("make BOARD=%s MULTITHREADS=%s %s" % (opt.board, multi_thread, params_str)) >> 8
             else:
                 if ext_scons_existed:
                     if params_str.find("V=1") >= 0:
-                        result = os.system("scons --verbose %s -j4" % params_str) >> 8
+                        result = os.system("scons --verbose -j%d %s" % (num, params_str)) >> 8
                     else:
-                        result = os.system("scons %s -j4" % params_str) >> 8
+                        result = os.system("scons -j%d %s" % (num, params_str)) >> 8
                 else:
-                    result = os.system("make %s" % params_str) >> 8
-
+                    result = os.system("make MULTITHREADS=%s %s" % (multi_thread, params_str)) >> 8
+            maketime = time.time() - starttime
+            m, s = divmod(maketime, 60)
+            put_string("Build takes %s Minutes %s Seconds." % (int(m), int(s)))
         for cmd in cmds:
             if cmd == "clean":
                 if opt.board:
